Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(549)

Unified Diff: content/browser/media/capture/aura_window_capture_machine.h

Issue 2881143003: Convert //content/browser/media to be clients of WakeLock mojo service. (Closed)
Patch Set: code rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/media/capture/aura_window_capture_machine.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/media/capture/aura_window_capture_machine.h
diff --git a/content/browser/media/capture/aura_window_capture_machine.h b/content/browser/media/capture/aura_window_capture_machine.h
index a5fbd594055d28d372308a6638759a75ad6ae3bb..244180719cc21d525b6a3522ab83ee2dfb77f7ea 100644
--- a/content/browser/media/capture/aura_window_capture_machine.h
+++ b/content/browser/media/capture/aura_window_capture_machine.h
@@ -10,6 +10,7 @@
#include "base/macros.h"
#include "base/memory/weak_ptr.h"
#include "content/browser/media/capture/cursor_renderer_aura.h"
+#include "device/wake_lock/public/interfaces/wake_lock_service.mojom.h"
#include "media/capture/content/screen_capture_device_core.h"
#include "ui/aura/window.h"
#include "ui/aura/window_observer.h"
@@ -21,10 +22,6 @@ namespace cc {
class CopyOutputResult;
} // namespace cc
-namespace device {
-class PowerSaveBlocker;
-} // namespace device
-
namespace viz {
class ReadbackYUVInterface;
}
@@ -125,9 +122,9 @@ class AuraWindowCaptureMachine
// Renders mouse cursor on frame.
std::unique_ptr<content::CursorRendererAura> cursor_renderer_;
// TODO(jiayl): Remove power_save_blocker_ when there is an API to keep the
// screen from sleeping for the drive-by web.
- std::unique_ptr<device::PowerSaveBlocker> power_save_blocker_;
+ device::mojom::WakeLockServicePtr wake_lock_;
// False while frame capture has been suspended. All other aspects of the
// machine are maintained.
« no previous file with comments | « no previous file | content/browser/media/capture/aura_window_capture_machine.cc » ('j') | no next file with comments »
@@ -125,9 +122,9 @@ class AuraWindowCaptureMachine
// Renders mouse cursor on frame.
std::unique_ptr<content::CursorRendererAura> cursor_renderer_;
- // TODO(jiayl): Remove power_save_blocker_ when there is an API to keep the
+ // TODO(jiayl): Remove wake_lock_ when there is an API to keep the
// screen from sleeping for the drive-by web.

Powered by Google App Engine
This is Rietveld 408576698